# knip

This module aims to make python coding hassle free!

### Usage

```python
from knip import sprint

sprint("hello", "world", end="#", sep="$")

sprint("3.14159265" * 314159265)
```

### Advantages

1) It displays large data (of any type) in a neat and organized manner.
2) Does not hang while printing, no matter how large the data may be.
3) Syntactically similar to in-built print function.
#### *no reason not to use it <3*

### Installation

Run the following to install:

```python
pip install knip
```

### Author

1) Email: nishant.aklecha@gmail.com
2) LinkedIn: https://www.linkedin.com/in/naklecha
3) CodeChef: https://www.codechef.com/users/naklecha
4) PYPI: https://pypi.org/user/naklecha
5) GitHub: https://github.com/Naklecha

##### *"Any suggestions would be appreciated"*
##### *"Help me make this module better by adding your own appropriate functions! Thanks!"*
